@@ -524,57 +524,7 @@ class raybaas_function():
         time.sleep(5)
         
 
-if __name__ == '__main__':
-#     pass
-    baas = raybaas_function(down_dir='F:\\download', driver="chrome")
-#     baas.drive.setWindowSize('max')
-#     
-#     baas.login('Admin', baas.s_user, baas.s_pass)
-#     time.sleep(3)
-    baas.login('User', baas.c_user, baas.c_pass)
-#     if(baas.user_exist('mrray1')==None):
-#         baas.add_user('mrray1', '123qaz', 'aaa@bbbxa.ccc', 'user')
-    time.sleep(3)
-#     
-#     userExist = baas.user_exist('mrray1')
-#     print(userExist)
-# #     baas.logout()
-#     if(baas.server_exist('192.168.1.166')==None):
-#         baas.add_server('247', '192.168.1.166', '22', 'root', 'mrray@2020')
-#     
-#     if(baas.server_exist('192.168.1.247')==None):
-#         baas.add_server('247', '192.168.1.247', '22', 'root', 'mrray@2020')
-# #         
-# #     time.sleep(3)
-#     if(baas.server_exist('192.168.1.247')!=None):
-#         baas.server_del('192.168.1.247')
-#     server = baas.server_exist('192.168.1.247')
-#     print(server)
-#     baas.order_apply('首页', '哈利波特', 'D:\CLionhh_jb51.rar')
-#     time.sleep(3)
-# 
-#     baas.chain_applay('perilong', 3, 1, 'kafka')
-#     baas.chain_applay('perilong', 3, 1, 'kafka')
-#     baas.chain_applay('perilong', 3, 1, 'raft')
-#     baas.chain_applay('mrray', 3, 1, 'pbft')
-#     baas.chain_applay('perilong', 3, 1, 'pbft')
-#     for i in range(5):
-#         baas.chain_del('perilong')
-
-    p_n = baas.chain_peer_num('mrray')
-    print(p_n)
-      
-    baas.drive.quit()
-    
-#     baas = raybaas_function(driver="firefox", down_dir='F:\download')
-# #     baas = raybaas_function(driver="chrome")
-#     baas.login('Admin', baas.s_user, baas.s_pass)
-# #     time.sleep(3)
-# #     
-# #     baas.order_download_attach()
-#     baas.chain_audit('mrray')
-#     time.sleep(5)
-#     baas.chain_deploy('mrray')
-# #     
-#     baas.drive.quit()
+# if __name__ == '__main__':
+# #     pass
+#     baas = raybaas_function(down_dir='F:\\download', driver="chrome")
     
\ No newline at end of file
